# WaybillsUpdateCustomFieldsUpdateRequestValue


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------

## Example

```python
from openapi_client.models.waybills_update_custom_fields_update_request_value import WaybillsUpdateCustomFieldsUpdateRequestValue

# TODO update the JSON string below
json = "{}"
# create an instance of WaybillsUpdateCustomFieldsUpdateRequestValue from a JSON string
waybills_update_custom_fields_update_request_value_instance = WaybillsUpdateCustomFieldsUpdateRequestValue.from_json(json)
# print the JSON string representation of the object
print(WaybillsUpdateCustomFieldsUpdateRequestValue.to_json())

# convert the object into a dict
waybills_update_custom_fields_update_request_value_dict = waybills_update_custom_fields_update_request_value_instance.to_dict()
# create an instance of WaybillsUpdateCustomFieldsUpdateRequestValue from a dict
waybills_update_custom_fields_update_request_value_from_dict = WaybillsUpdateCustomFieldsUpdateRequestValue.from_dict(waybills_update_custom_fields_update_request_value_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


